pywws.Logger — pywws 13.06_r1023 documentation

### Navigation

- index
- modules |
- précédent |
- pywws 13.06_r1023 documentation »
- Programmes et des modules Python »

# pywws.Logger

Code commun pour l’enregistrement d’informations et d’erreurs.

Fonctions

`ApplicationLogger`(verbose[, logfile]) |

`pywws.Logger.` `ApplicationLogger`(verbose, logfile=None)

### Navigation

- index
- modules |
- précédent |
- pywws 13.06_r1023 documentation »
- Programmes et des modules Python »